#include "daemon.h"
#include <QCoreApplication>

int main(int argc, char *argv[])
{
    QCoreApplication a(argc, argv);
    a.setOrganizationName("callerx");
    a.setApplicationName("callerx");
    CallerXDaemon* b = new CallerXDaemon();
    QObject::connect(b, SIGNAL(quit()), &a, SLOT(quit()));
    b->Start();
    return a.exec();
}
